package com.biganto.visual.roompark.presentation.screen.favorites.util

import android.view.View
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.StaggeredGridLayoutManager
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.domain.model.AlbumSortedModel
import com.biganto.visual.roompark.domain.model.PhotoModel
import com.biganto.visual.roompark.domain.model.PhotoResolutionModel
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonRecyclerAdapter
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonViewHolder
import com.biganto.visual.roompark.util.view_utils.image_view.RoundedImageView
import com.google.android.material.textview.MaterialTextView
import com.squareup.picasso.Picasso
import java.util.concurrent.Executors

/**
 * Created by Vladislav Bogdashkin on 16.10.2019.
 */


class AlbumListAdapter : CommonRecyclerAdapter<AlbumViewHolder, AlbumSortedModel>() {
    override val vhKlazz = AlbumViewHolder::class

    override fun getVhLayout(): Int = R.layout.date_album_viewholder
}

    class AlbumViewHolder(itemView: View) : CommonViewHolder<AlbumSortedModel>(itemView) {

        @BindView(R.id.date_title_textview)
        lateinit var albumTitle: MaterialTextView
        @BindView(R.id.photos_recyclerview)
        lateinit var photosRecyclerView: RecyclerView
//        @BindView(R.id.camStatusIcon) lateinit var camStatusIcon:ImageView

        override fun onViewBound(model: AlbumSortedModel) {
            albumTitle.text = model.title
            photosRecyclerView.isNestedScrollingEnabled = false
            photosRecyclerView.layoutManager =
                StaggeredGridLayoutManager(4, RecyclerView.VERTICAL)
            val adapter = PhotosAdapter()
            photosRecyclerView.adapter = adapter
            photosRecyclerView.itemAnimator = null
            adapter.setItems(model.items)
        }
    }

class PhotosAdapter : CommonRecyclerAdapter<PhotosViewHolder, PhotoModel>() {
    override val vhKlazz = PhotosViewHolder::class

    override fun getVhLayout(): Int = R.layout.photo_preview_viewholder
}

val exSercv = Executors.newFixedThreadPool(4)
val  picoAbuilder= Picasso.Builder(RoomParkApplication.component.provideAppContext())
    .executor(exSercv)
    .build()

class PhotosViewHolder(itemView: View) : CommonViewHolder<PhotoModel>(itemView) {

    @BindView(R.id.photo_preview_imageview) lateinit var photoPreview: RoundedImageView

    override fun onViewBound(model: PhotoModel) {
        model.resolutionList.lowelest()?.let {
                picoAbuilder
                .load(it.url)
                .centerCrop()
                .fit()
                .into(photoPreview)
        }}
}

fun List<PhotoResolutionModel>.lowelest() =
    this.minBy { it.resWidth * it.resHeight }